import java.io.*;
import java.net.ServerSocket;
import java.net.Socket;
import java.nio.charset.StandardCharsets;
import java.text.SimpleDateFormat;
import java.util.Date;

public class BcowServer {

    private static final int PORT = 9999;

    public static void main(String[] args) {
        try (ServerSocket serverSocket = new ServerSocket(PORT)) {
            System.out.println("Server is listening on port " + PORT);

            while (true) {
                new ClientHandler(serverSocket.accept()).start();
            }
        } catch (IOException ex) {
            ex.printStackTrace();
        }
    }

    private static class ClientHandler extends Thread {
        private Socket socket;

        public ClientHandler(Socket socket) {
            this.socket = socket;
        }

        public void run() {
            try (InputStream input = socket.getInputStream()) {
                BufferedReader reader = new BufferedReader(new InputStreamReader(input, StandardCharsets.UTF_8));

                String data = reader.readLine();
                if (data != null) {
                    processPacketData(data);
                }
            } catch (IOException ex) {
                ex.printStackTrace();
            }
        }

        private void processPacketData(String data) {
            try {
                String[] parts = data.split("\\|");

                if (parts.length >= 4) {
                    String id = parts[0].split(":")[1].trim();
                    String name = parts[1].split(":")[1].trim();
                    String timezone = parts[2].split(":")[1].trim();
                    String packetData = parts[3].split(":")[1].trim();

                    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
                    String date = sdf.format(new Date());
                    SimpleDateFormat timeFormat = new SimpleDateFormat("HH-mm-ss");
                    String time = timeFormat.format(new Date());

                    File dir = new File(name + "_" + id + "/" + date);
                    if (!dir.exists()) {
                        dir.mkdirs();
                    }

                    try (BufferedWriter writer = new BufferedWriter(new FileWriter(new File(dir, time + ".txt")))) {
                        writer.write(packetData);
                    } catch (IOException e) {
                        e.printStackTrace();
                    }

                    // Log the received packet data for verification
                    System.out.println("Received ID:" + id + " Name:" + name + " Timezone:" + timezone + " Data:" + packetData);
                } else {
                    System.err.println("Malformed data received: " + data);
                }
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }
}
